==> django-localflavor_1.2.orig.tar.gz: django-localflavor-1.2/localflavor/lt/lt_choices.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from django.utils.translation import ugettext_lazy as _

#: Alphabetically sorted list of Lithuanian counties.
COUNTY_CHOICES = (
    ('alytus', _('Alytus')),
    ('kaunas', _('Kaunas')),
    ('klaipeda', _('Klaipėda')),
    ('mariampole', _('Mariampolė')),
    ('panevezys', _('Panevėžys')),
    ('siauliai', _('Šiauliai')),
    ('taurage', _('Tauragė')),
    ('telsiai', _('Telšiai')),
    ('utena', _('Utena')),
    ('vilnius', _('Vilnius')),
)

#: Alphabetically sorted lists of Lithuanian municipalities.
MUNICIPALITY_CHOICES = (
    ('akmene', _('Akmenė district')),
    ('alytus_c', _('Alytus city')),
    ('alytus', _('Alytus district')),
    ('anyksciai', _('Anykščiai district')),
    ('birstonas', _('Birštonas')),
    ('birzai', _('Biržai district')),
    ('druskininkai', _('Druskininkai')),
    ('elektrenai', _('Elektrėnai')),
    ('ignalina', _('Ignalina district')),
    ('jonava', _('Jonava district')),
    ('joniskis', _('Joniškis district')),
    ('jurbarkas', _('Jurbarkas district')),
    ('kaisiadorys', _('Kaišiadorys district')),
    ('kalvarija', _('Kalvarija')),
    ('kaunas_c', _('Kaunas city')),
    ('kaunas', _('Kaunas district')),
    ('kazluruda', _('Kazlų Rūda')),
    ('kedainiai', _('Kėdainiai district')),
    ('kelme', _('Kelmė district')),
    ('klaipeda_c', _('Klaipėda city')),
    ('klaipeda', _('Klaipėda district')),
    ('kretinga', _('Kretinga district')),
    ('kupiskis', _('Kupiškis district')),
    ('lazdijai', _('Lazdijai district')),
    ('marijampole', _('Marijampolė')),
    ('mazeikiai', _('Mažeikiai district')),
    ('moletai', _('Molėtai district')),
    ('neringa', _('Neringa')),
    ('pagegiai', _('Pagėgiai')),
    ('pakruojis', _('Pakruojis district')),
    ('palanga', _('Palanga city')),
    ('panevezys_c', _('Panevėžys city')),
    ('panevezys', _('Panevėžys district')),
    ('pasvalys', _('Pasvalys district')),
    ('plunge', _('Plungė district')),
    ('prienai', _('Prienai district')),
    ('radviliskis', _('Radviliškis district')),
    ('raseiniai', _('Raseiniai district')),
    ('rietavas', _('Rietavas')),
    ('rokiskis', _('Rokiškis district')),
    ('skuodas', _('Skuodas district')),
    ('sakiai', _('Šakiai district')),
    ('salcininkai', _('Šalčininkai district')),
    ('siauliai_c', _('Šiauliai city')),
    ('siauliai', _('Šiauliai district')),
    ('silale', _('Šilalė district')),
    ('silute', _('Šilutė district')),
    ('sirvintos', _('Širvintos district')),
    ('svencionys', _('Švenčionys district')),
    ('taurage', _('Tauragė district')),
    ('telsiai', _('Telšiai district')),
    ('trakai', _('Trakai district')),
    ('ukmerge', _('Ukmergė district')),
    ('utena', _('Utena district')),
    ('varena', _('Varėna district')),
    ('vilkaviskis', _('Vilkaviškis district')),
    ('vilnius_c', _('Vilnius city')),
    ('vilnius', _('Vilnius district')),
    ('visaginas', _('Visaginas')),
    ('zarasai', _('Zarasai district')),
)

==> django-localflavor-3.0.1.tar.gz: django-localflavor-3.0.1/localflavor/lt/lt_choices.py <==
from django.utils.translation import gettext_lazy as _

#: Alphabetically sorted list of Lithuanian counties.
COUNTY_CHOICES = (
    ('alytus', _('Alytus')),
    ('kaunas', _('Kaunas')),
    ('klaipeda', _('Klaipėda')),
    ('mariampole', _('Mariampolė')),
    ('panevezys', _('Panevėžys')),
    ('siauliai', _('Šiauliai')),
    ('taurage', _('Tauragė')),
    ('telsiai', _('Telšiai')),
    ('utena', _('Utena')),
    ('vilnius', _('Vilnius')),
)

#: Alphabetically sorted lists of Lithuanian municipalities.
MUNICIPALITY_CHOICES = (
    ('akmene', _('Akmenė district')),
    ('alytus_c', _('Alytus city')),
    ('alytus', _('Alytus district')),
    ('anyksciai', _('Anykščiai district')),
    ('birstonas', _('Birštonas')),
    ('birzai', _('Biržai district')),
    ('druskininkai', _('Druskininkai')),
    ('elektrenai', _('Elektrėnai')),
    ('ignalina', _('Ignalina district')),
    ('jonava', _('Jonava district')),
    ('joniskis', _('Joniškis district')),
    ('jurbarkas', _('Jurbarkas district')),
    ('kaisiadorys', _('Kaišiadorys district')),
    ('kalvarija', _('Kalvarija')),
    ('kaunas_c', _('Kaunas city')),
    ('kaunas', _('Kaunas district')),
    ('kazluruda', _('Kazlų Rūda')),
    ('kedainiai', _('Kėdainiai district')),
    ('kelme', _('Kelmė district')),
    ('klaipeda_c', _('Klaipėda city')),
    ('klaipeda', _('Klaipėda district')),
    ('kretinga', _('Kretinga district')),
    ('kupiskis', _('Kupiškis district')),
    ('lazdijai', _('Lazdijai district')),
    ('marijampole', _('Marijampolė')),
    ('mazeikiai', _('Mažeikiai district')),
    ('moletai', _('Molėtai district')),
    ('neringa', _('Neringa')),
    ('pagegiai', _('Pagėgiai')),
    ('pakruojis', _('Pakruojis district')),
    ('palanga', _('Palanga city')),
    ('panevezys_c', _('Panevėžys city')),
    ('panevezys', _('Panevėžys district')),
    ('pasvalys', _('Pasvalys district')),
    ('plunge', _('Plungė district')),
    ('prienai', _('Prienai district')),
    ('radviliskis', _('Radviliškis district')),
    ('raseiniai', _('Raseiniai district')),
    ('rietavas', _('Rietavas')),
    ('rokiskis', _('Rokiškis district')),
    ('skuodas', _('Skuodas district')),
    ('sakiai', _('Šakiai district')),
    ('salcininkai', _('Šalčininkai district')),
    ('siauliai_c', _('Šiauliai city')),
    ('siauliai', _('Šiauliai district')),
    ('silale', _('Šilalė district')),
    ('silute', _('Šilutė district')),
    ('sirvintos', _('Širvintos district')),
    ('svencionys', _('Švenčionys district')),
    ('taurage', _('Tauragė district')),
    ('telsiai', _('Telšiai district')),
    ('trakai', _('Trakai district')),
    ('ukmerge', _('Ukmergė district')),
    ('utena', _('Utena district')),
    ('varena', _('Varėna district')),
    ('vilkaviskis', _('Vilkaviškis district')),
    ('vilnius_c', _('Vilnius city')),
    ('vilnius', _('Vilnius district')),
    ('visaginas', _('Visaginas')),
    ('zarasai', _('Zarasai district')),
)
